<?php

namespace App\Repositories\Eloquent;

use App\Repositories\Contracts\BhSoitemsRepository;
use App\Repositories\Contracts\BhSordersRepository;
use App\Repositories\Criteria\RequestCriteria;
use App\Repositories\Models\BhSoitems;
use App\Repositories\Eloquent\BaseRepository;

use Prettus\Validator\Contracts\ValidatorInterface;

/**
 * Class UserRepositoryEloquent.
 */
class BhSoitemsRepositoryEloquent extends BaseRepository implements BhSoitemsRepository
{
    protected $fieldSearchable = [
    ];

    /**
     * Specify Model class name.
     *
     * @return string
     */
    public function model()
    {
        return BhSoitems::class;
    }

    /**
     * Boot up the repository, pushing criteria.
     *
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function boot()
    {
        $this->pushCriteria(app(RequestCriteria::class));
    }

    /**
     * 获取订单详情
     * @param $orderId
     * @return \Illuminate\Database\Eloquent\Builder[]|\Illuminate\Database\Eloquent\Collection
     */
    public function getSorderItemsDetailFromOrderId($orderId)
    {
        $order = app(BhSordersRepository::class)->find($orderId);
        if(!$order){
            throw new \LogicException('该订单不存在!',500);
        }

        //查询订单的详情
        $soItems = BhSoitems::query()
            ->join('products','soitems.p_id','products.p_id')
            ->join('chemicals','products.c_id','chemicals.c_id')
            ->join('brands','products.b_id','brands.b_id')
            ->where('soitems.so_id',$order->so_id)->get();

        return $soItems;
    }

    /**
     * 根据si_id获取订单明细项
     * @param $si_id
     * @return \Illuminate\Database\Eloquent\Builder[]|\Illuminate\Database\Eloquent\Collection
     */
    public function getSorderItemFromItemId($si_id)
    {
        $item = $this->find($si_id);
        if(!$item){
            throw new \LogicException('该订单项不存在!',500);
        }

        //查询订单的详情
        $soItems = BhSoitems::query()
            ->join('products','soitems.p_id','products.p_id')
            ->where('soitems.si_id',$si_id)->get();

        return $soItems;
    }
}
